@@ -2,7 +2,6 @@
  * Copyright © 2020 VMware, Inc.
  */
 
-#include <stdint.h>
 #include <systemd/sd-bus.h>
 
 #include "alloc-util.h"
@@ -32,3 +31,5 @@ int dbus_revert_resolve_link(int ifindex);
 int dbus_get_dns_domains_from_resolved(DNSDomains **domains);
 int dbus_network_reload(void);
 int dbus_reconfigure_link(int ifindex);
+
+int dbus_get_system_property_from_networkd(const char *p, char **ret);
